const { join } = require("path");
require("dotenv").config({ path: join(__dirname, ".env") });
const DiscordRPC = require("discord-rpc");
const fetch = require("node-fetch");

const interval = 30000;

const sleep = async (ms) => {
    return new Promise((resolve) => setTimeout(resolve, ms));
}

const getCurrentPlayers = async () => {
    const apiURL = "https://play.retro-mmo.com/players.json";
    const players = await fetch(apiURL).then((res) => {
        if (!res.ok) {
            return [];
        };
        return res.json();
    });
    return players;
}

class DiscordConnection {
    constructor(mainWindow) {
        this.win = mainWindow;
        this.startTime = Date.now();
    }

    async login() {
        try {
            this.rpc = new DiscordRPC.Client({ transport: "ipc" });
            await this.rpc.login({
                clientId: process.env.DISCORD_APPLICATION_ID,
            });
        }
        catch {
            console.error("Failed logging in to discord. Trying again in 30 seconds");
            await sleep(interval);
            return this.login();
        }
    }

    async init() {
        await this.login();
        this.syncActivity();
    }

    async syncActivity() {
        while (true) {
            const players = await getCurrentPlayers();
            await this.rpc.setActivity({
                buttons: [
                    {
                        label: "Play the game",
                        url: "https://retro-mmo.com/play",
                    },
                    {
                        label: "Join Discord",
                        url: "https://discord.gg/retrommo",
                    },
                ],
                instance: true,
                largeImageKey: "logo",
                largeImageText: "RetroMMO",
                ...(players.length
                    ? {
                        details: `${players.length} current players`,
                    }
                    : {}),
            });
            await sleep(interval);
        }
    }
}

module.exports = DiscordConnection;
